==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/content/messages/hu/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Azoknak is látható, akik nem tagja ennek a közösségnek)',
    '<strong>Confirm</strong> post deletion' => 'Bejegyzés törlésének <strong>megerősítése</strong>',
    '<strong>Move</strong> content' => 'Tartalom <strong>áthelyezése</strong>',
    '<strong>Permalink</strong> to this post' => '<strong>Hivatkozás</strong> ehhez a bejegyzéshez',
    'Add a member to notify' => 'Értesítendő tag hozzáadása',
    'Add tag...' => 'Címke hozzáadása…',
    'Archived' => 'Archivált',
    'Attach Files' => 'Csatolt fájlok',
    'Back to stream' => 'Vissza a hírfolyamhoz',
    'Cancel' => 'Mégsem',
    'Cancel Edit' => 'Szerkesztés visszavonása',
    'Change to "Private"' => 'Legyen zárt',
    'Change to "Public"' => 'Legyen nyilvános',
    'Comments are locked' => 'A hozzászólások zárolva',
    'Comments are unlocked' => 'A hozzászólások feloldva',
    'Content' => 'Tartalom',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Érvénytelen a csatolt contentcontainer_id tartalomcímke',
    'Content has been moved to {spacename}' => 'A tartalom át lett helyezve a(z) {spacename} közösségbe',
    'Content visibility' => 'Tartalom láthatósága',
    'Could not delete content!' => 'A tartalmat nem lehetett törölni!',
    'Could not find requested content!' => 'A kért tartalom nem található!',
    'Created at:' => 'Készült:',
    'Created by me' => 'Általam létrehozva',
    'Creation time' => 'Létrehozás dátuma',
    'Delete' => 'Törlés',
    'Do you really want to delete this post? All likes and comments will be lost!' => 'Biztos, hogy törölni szeretnéd ezt a bejegyzést? Az összes kedvelés és hozzászólás elvész!',
    'Edit' => 'Szerkesztés',
    'Filter' => 'Szűrés',
    'I\'m involved' => 'Ahol részt veszek',
    'Invalid content id given!' => 'A megadott tartalomazonosító érvénytelen!',
    'Invalid request method!' => 'Érvénytelen lekérési módszer!',
    'Invalid space selection.' => 'Érvénytelen közösségválasztás.',
    'Last update' => 'Utolsó frissítés',
    'Last updated {time}' => 'Utolsó frissítés: {time}',
    'Load more' => 'Továbbiak betöltése',
    'Lock comments' => 'Zárolt hozzászólások',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'A rögzített elemek maximális száma elérve! <br> Egyszerre legfeljebb {count} elemet lehet rögzíteni.',
    'Move content' => 'Tartalom áthelyezése',
    'Move to archive' => 'Archiválás',
    'No matches with your selected filters!' => 'A kiválasztott szűrőkkel nincs találat!',
    'No tags found for the given query' => 'Az adott lekérdezéshez nem találtunk címkéket',
    'None' => 'Nincs',
    'Nothing here yet!' => 'Nincs még itt semmi!',
    'Notify members' => 'Tagok értesítése',
    'Permalink' => 'Hivatkozás',
    'Pin to top' => 'Rögzítés felülre',
    'Pinned' => 'Rögzített',
    'Private' => 'Zárt',
    'Public' => 'Nyilvános',
    'Select type...' => 'Típus kiválasztása...',
    'Specify who can see this content.' => 'Meghatározza ki láthatja ezt a tartalmat.',
    'Submit' => 'Küldés',
    'Tag' => 'Címke',
    'Target Space' => 'Célközösség',
    'The author of this content is not allowed to create private content within the selected space.' => 'A tartalom szerzője nem hozhat létre zárt tartalmat a kiválasztott közösségben.',
    'The author of this content is not allowed to create public content within the selected space.' => 'A tartalom szerzője nem hozhat létre nyilvános tartalmat a kiválasztott közösségben.',
    'The author of this content is not allowed to create this type of content within this space.' => 'A tartalom szerzője nem hozhat létre ilyen típusú tartalmat ezen a területen.',
    'The content can\'t be moved to its current space.' => 'A tartalmat nem lehet áthelyezni a jelenlegi helyére.',
    'The content has been archived.' => 'Ez a tartalom archiválva lett.',
    'The content has been deleted.' => 'A tartalmat törölték.',
    'The content has been unarchived.' => 'Tartalom archiválás visszavonva.',
    'The given name is already in use.' => 'A megadott név már használatban van.',
    'The module {moduleName} is not enabled on the selected target space.' => 'A {moduleName} modul nincs engedélyezve a kiválasztott célközösségben.',
    'This action is disabled!' => 'Ez a művelet ki van kapcsolva!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Ez a tartalomtípus egy hiányzó modul-id beállítás miatt nem helyezhető át.',
    'This content type can\'t be moved.' => 'Ez a tartalomtípus nem mozgatható.',
    'This space is archived.' => 'Ez egy archivált közösség',
    'This space is not visible!' => 'A közösség nem látható!',
    'Topics' => 'Témakörök',
    'Turn off notifications' => 'Nem kérek értesítéseket',
    'Turn on notifications' => 'Kérek értesítéseket',
    'Unarchive' => 'Archiválás visszavonása',
    'Unlock comments' => 'Hozzászólások feloldása',
    'Unpin' => 'Rögzítés visszavonása',
    'Updated' => 'Frissítve',
    'Visible also to unregistered users' => 'Nem regisztrált tagoknak is látható',
    'Visible only to you' => 'Csak neked látható',
    'Visible to all Space members' => 'Összes közösségi tagnak látható',
    'Visible to all signed in users' => 'Minden bejelentkezett felhasználónak látható',
    'Visible to friends of {displayName}' => '{displayName} barátainak látható',
    'Visible to you and {displayName}' => 'Neked és neki látható: {displayName}',
    'Visible to your friends' => 'Látható a barátaidnak',
    'With attachments' => 'Fájl csatolmányokkal',
    'You do not have the permission to move this content to the given space.' => 'Nincs jogosultságod a tartalomnak az adott közösségbe történő áthelyezésére.',
    'You do not have the permission to move this content.' => 'Nincs jogosultságod a tartalom áthelyezésére.',
    'Your last edit state has been saved!' => 'Az utolsó szerkesztési állapotod mentve!',
    'in' => 'itt',
    '<strong>Delete</strong> content?' => '',
    'Confirm' => '',
    'New Updates Available!' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/content/messages/hu/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Azoknak is látható, akik nem tagja ennek a közösségnek)',
    '<strong>Delete</strong> content?' => '<strong>Törlöd</strong> a bejegyzést?',
    '<strong>Move</strong> content' => 'Tartalom <strong>áthelyezése</strong>',
    '<strong>Permalink</strong> to this post' => '<strong>Hivatkozás</strong> ehhez a bejegyzéshez',
    '<strong>Scheduling</strong> Options' => '<strong>Ütemezési</strong> beállítások',
    'Activate scheduling' => 'Ütemezés aktiválása',
    'Add a member to notify' => 'Értesítendő tag hozzáadása',
    'Add tag...' => 'Címke hozzáadása…',
    'Archived' => 'Archivált',
    'Attach Files' => 'Csatolt fájlok',
    'Back to stream' => 'Vissza a hírfolyamhoz',
    'Cancel' => 'Mégsem',
    'Cancel Edit' => 'Szerkesztés visszavonása',
    'Cannot notify the author.' => 'A szerzőt nem lehet értesíteni.',
    'Change to "Private"' => 'Legyen zárt',
    'Change to "Public"' => 'Legyen nyilvános',
    'Comments are locked' => 'A hozzászólások zárolva',
    'Comments are unlocked' => 'A hozzászólások feloldva',
    'Configure' => 'Konfiguráció',
    'Confirm' => 'Megerősít',
    'Content' => 'Tartalom',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Érvénytelen a csatolt contentcontainer_id tartalomcímke',
    'Content has been moved to {spacename}' => 'A tartalom át lett helyezve a(z) {spacename} közösségbe',
    'Could not find requested content!' => 'A kért tartalom nem található!',
    'Create as draft' => 'Létrehozás piszkozatként',
    'Created at:' => 'Készült:',
    'Created by me' => 'Általam létrehozva',
    'Creation time' => 'Létrehozás dátuma',
    'Delete' => 'Törlés',
    'Deleted' => 'Törölve',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => 'Törli ezt a tartalmat, beleértve az összes megjegyzést és mellékletet?<br><br>Megjegyzés: Ha egy adatfolyam-bejegyzést egy modul használatával hoztak létre, akkor az eredeti tartalom is törlődik, amelyhez ez a bejegyzés kapcsolódik.',
    'Draft' => 'Piszkozat',
    'Edit' => 'Szerkesztés',
    'Enable' => 'Engedélyezés',
    'Enabled' => 'Aktiválva',
    'Filter' => 'Szűrés',
    'Hidden' => 'Rejtett',
    'I\'m involved' => 'Ahol részt veszek',
    'Invalid content id given!' => 'A megadott tartalomazonosító érvénytelen!',
    'Invalid request method!' => 'Érvénytelen lekérési módszer!',
    'Invalid space selection.' => 'Érvénytelen közösségválasztás.',
    'Last update' => 'Utolsó frissítés',
    'Last updated {time}' => 'Utolsó frissítés: {time}',
    'Load more' => 'Továbbiak betöltése',
    'Lock comments' => 'Zárolt hozzászólások',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'A rögzített elemek maximális száma elérve! <br> Egyszerre legfeljebb {count} elemet lehet rögzíteni.',
    'Move content' => 'Tartalom áthelyezése',
    'Move to archive' => 'Archiválás',
    'New Updates Available!' => 'Új bejegyzések érkeztek!',
    'No matches with your selected filters!' => 'A kiválasztott szűrőkkel nincs találat!',
    'No tags found for the given query' => 'Az adott lekérdezéshez nem találtunk címkéket',
    'None' => 'Nincs',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => 'Megjegyzés: Technikai okok miatt előfordulhat néhány perces késés.',
    'Nothing here yet!' => 'Nincs még itt semmi!',
    'Notify members' => 'Tagok értesítése',
    'Permalink' => 'Hivatkozás',
    'Pin to top' => 'Rögzítés felülre',
    'Pinned' => 'Rögzített',
    'Private' => 'Zárt',
    'Public' => 'Nyilvános',
    'Publish draft' => 'Piszkozat közzététele',
    'Save as draft' => 'Mentés piszkozatként',
    'Save scheduling' => 'Ütemezés mentése',
    'Schedule publication' => 'A megjelenés ütemezése',
    'Scheduled for {dateTime}' => 'Időpont: {dateTime}',
    'Select type...' => 'Típus kiválasztása...',
    'Specify who can see this content.' => 'Meghatározza ki láthatja ezt a tartalmat.',
    'Submit' => 'Küldés',
    'Tag' => 'Címke',
    'Target Space' => 'Célközösség',
    'The author of this content is not allowed to create private content within the selected space.' => 'A tartalom szerzője nem hozhat létre zárt tartalmat a kiválasztott közösségben.',
    'The author of this content is not allowed to create public content within the selected space.' => 'A tartalom szerzője nem hozhat létre nyilvános tartalmat a kiválasztott közösségben.',
    'The author of this content is not allowed to create this type of content within this space.' => 'A tartalom szerzője nem hozhat létre ilyen típusú tartalmat ezen a területen.',
    'The content can\'t be moved to its current space.' => 'A tartalmat nem lehet áthelyezni a jelenlegi helyére.',
    'The content cannot be published!' => 'A tartalom nem publikálható!',
    'The content has been archived.' => 'Ez a tartalom archiválva lett.',
    'The content has been deleted.' => 'A tartalmat törölték.',
    'The content has been successfully published.' => 'A tartalom közzététele sikeresen megtörtént.',
    'The content has been unarchived.' => 'Tartalom archiválás visszavonva.',
    'The given name is already in use.' => 'A megadott név már használatban van.',
    'The module {moduleName} is not enabled on the selected target space.' => 'A {moduleName} modul nincs engedélyezve a kiválasztott célközösségben.',
    'This action is disabled!' => 'Ez a művelet ki van kapcsolva!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Ez a tartalomtípus egy hiányzó modul-id beállítás miatt nem helyezhető át.',
    'This content type can\'t be moved.' => 'Ez a tartalomtípus nem mozgatható.',
    'This space is archived.' => 'Ez egy archivált közösség',
    'This space is not visible!' => 'A közösség nem látható!',
    'Topics' => 'Témakörök',
    'Turn off notifications' => 'Nem kérek értesítéseket',
    'Turn on notifications' => 'Kérek értesítéseket',
    'Unarchive' => 'Archiválás visszavonása',
    'Unlock comments' => 'Hozzászólások feloldása',
    'Unpin' => 'Rögzítés visszavonása',
    'Updated' => 'Frissítve',
    'Visible also to unregistered users' => 'Nem regisztrált tagoknak is látható',
    'Visible only to you' => 'Csak neked látható',
    'Visible to all Space members' => 'Összes közösségi tagnak látható',
    'Visible to all signed in users' => 'Minden bejelentkezett felhasználónak látható',
    'Visible to friends of {displayName}' => '{displayName} barátainak látható',
    'Visible to you and {displayName}' => 'Neked és neki látható: {displayName}',
    'Visible to your friends' => 'Látható a barátaidnak',
    'With attachments' => 'Fájl csatolmányokkal',
    'You cannot block the space owner!' => 'Nem tudod tiltani a közösség tulajdonosát!',
    'You cannot block the user of the same container!' => 'Nem tilthatod le ugyanazon tároló felhasználóját!',
    'You cannot block yourself!' => 'Nem tudod letiltani saját magadat!',
    'You do not have the permission to move this content to the given space.' => 'Nincs jogosultságod a tartalomnak az adott közösségbe történő áthelyezésére.',
    'You do not have the permission to move this content.' => 'Nincs jogosultságod a tartalom áthelyezésére.',
    'Your last edit state has been saved!' => 'Az utolsó szerkesztési állapotod mentve!',
    'in' => 'itt',
    'Advanced Content Search' => '',
];
